##############################################################################
# cmake configuration file for PandoraMonitoring
#
# requires:
#   MacroCheckPackageLibs.cmake for checking package libraries
#
# returns following variables:
#
#   PandoraMonitoring_FOUND      : set to TRUE if PandoraMonitoring found
#       if FIND_PACKAGE called with REQUIRED and COMPONENTS arguments
#       PandoraMonitoring_FOUND is only set to TRUE if ALL components are also found
#       if REQUIRED is NOT set components may or may not be available
#
#   PandoraMonitoring_ROOT       : path to this PandoraMonitoring installation
#   PandoraMonitoring_VERSION    : package version
#   PandoraMonitoring_LIBRARIES  : list of PandoraMonitoring libraries (NOT including COMPONENTS)
#   PandoraMonitoring_INCLUDE_DIRS  : list of paths to be used with INCLUDE_DIRECTORIES
#   PandoraMonitoring_LIBRARY_DIRS  : list of paths to be used with LINK_DIRECTORIES
#   PandoraMonitoring_COMPONENT_LIBRARIES      : list of PandoraMonitoring component libraries
#   PandoraMonitoring_${COMPONENT}_FOUND       : set to TRUE or FALSE for each library
#   PandoraMonitoring_${COMPONENT}_LIBRARY     : path to individual libraries
#   PandoraMonitoring_${COMPONENT}_LIB_DEPENDS : individual library dependencies
#
# @author Jan Engels, Desy
##############################################################################

SET( PandoraMonitoring_ROOT "$ENV{PANDORA_FQ_DIR}" )
SET( PandoraMonitoring_VERSION "03.04.01" )


# ---------- include dirs -----------------------------------------------------
# do not store find results in cache
SET( PandoraMonitoring_INCLUDE_DIRS PandoraMonitoring_INCLUDE_DIRS-NOTFOUND )
MARK_AS_ADVANCED( PandoraMonitoring_INCLUDE_DIRS )

FIND_PATH( PandoraMonitoring_INCLUDE_DIRS
	NAMES PandoraMonitoringApi.h
	PATHS ${PandoraMonitoring_ROOT}/include
	NO_DEFAULT_PATH
)



# ---------- libraries --------------------------------------------------------
INCLUDE( "$ENV{PANDORA_FQ_DIR}/pandora-v03-11-01/PandoraPFA-v03-11-01/cmakemodules/MacroCheckPackageLibs.cmake" )

# only standard libraries should be passed as arguments to CHECK_PACKAGE_LIBS
# additional components are set by cmake in variable PKG_FIND_COMPONENTS
# first argument should be the package name
CHECK_PACKAGE_LIBS( PandoraMonitoring PandoraMonitoring )




# ---------- libraries dependencies -------------------------------------------
# this sets PandoraMonitoring_${COMPONENT}_LIB_DEPENDS variables
INCLUDE( "${PandoraMonitoring_ROOT}/lib/cmake/PandoraMonitoringLibDeps.cmake" )
 



# ---------- final checking ---------------------------------------------------
INCLUDE( FindPackageHandleStandardArgs )
# set PANDORAMONITORINGNEW_FOUND to TRUE if all listed variables are TRUE and not empty
# PandoraMonitoring_COMPONENT_VARIABLES will be set if FIND_PACKAGE is called with REQUIRED argument
FIND_PACKAGE_HANDLE_STANDARD_ARGS( PandoraMonitoring DEFAULT_MSG PandoraMonitoring_ROOT PandoraMonitoring_INCLUDE_DIRS PandoraMonitoring_LIBRARIES ${PandoraMonitoring_COMPONENT_VARIABLES} )

SET( PandoraMonitoring_FOUND ${PANDORAMONITORINGNEW_FOUND} )
